import { OnDestroy, OnInit } from '@angular/core';
import { LfI18n, LfMatchingRoute, LfRouter, LfStorage, PathBased } from '@lightweightform/core';
import { Identifier } from '@lightweightform/storage';
/**
 * Entry for an item of the tree-nav.
 */
export declare class TreeEntryComponent extends PathBased implements OnInit, OnDestroy {
    private lfRouter;
    /**
     * Whether this tree-entry is to be displayed as the root one (in which case
     * its label isn't shown anywhere and its children are displayed one after the
     * other). The entry can be displayed as root only when its schema is complex.
     * A button is displayed at the end of the list when there are optional values
     * to be added or to add a new element in case the schema is a list.
     */
    displayAsRoot: boolean;
    /**
     * Internal input used to make a tree only show entries that render in the
     * same outlet (values that should render inside other components shouldn't be
     * part of the same tree).
     */
    _componentLevel: number;
    private disposeOnDisplayAsRootChanges;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter);
    /**
     * Label associated with this value.
     */
    get label(): string;
    /**
     * Message used to ask the user to retry validating the value.
     */
    get retryValidateText(): string;
    get addOptionalValueButtonText(): string;
    get addValueToListButtonText(): string;
    get matchingRoutes(): LfMatchingRoute[];
    get navigateableRoute(): LfMatchingRoute | null;
    get url(): string | null;
    get isActive(): boolean;
    get isList(): boolean;
    get childrenIds(): Identifier[];
    get nonNullChildrenIds(): Identifier[];
    get nullChildrenIds(): Identifier[];
    ngOnInit(): void;
    ngOnDestroy(): void;
    childLabel(id: Identifier): string;
    addToList(): void;
    initializeChild(id: string): void;
    protected validatePath(): void;
    /**
     * The "component" level of the provided matching route (basically the number
     * of outlets used by the route).
     * @param matchingRoute Matching of a route with a provided path.
     * @returns Component level for the matching route.
     */
    private matchingRouteComponentLevel;
}
